Learn R Programming

segmented (version 0.2-3)

segmented-package: Segmented relationships in regression models

Description

Estimation of Generalized Linear Models with piecewise linear relationships having a fixed number of break-points.

Arguments

Details

ll{ Package: segmented Type: Package Version: 0.2-3 Date: 2007-10-26 License: GPL } Package segmented is aimed to estimate linear and generalized linear models having one or more segmented relationships in the linear predictor. Estimates of the slopes and of the possibly multiple breakpoints are provided. The package includes testing/estimating functions and methods to print, summarize and plot the results.

References

Seber, G.A.F. and Wild, C.J. (1989) Nonlinear Regression. Wiley, New York. Muggeo, V.M.R. (2003) Estimating regression models with unknown break-points. Statistics in Medicine 22, 3055--3071. Davies, R.B. (1987) Hypothesis testing when a nuisance parameter is present only under the alternative. Biometrika 74, 33--43.