Learn R Programming

segmented (version 0.2-3)

simulData: Simulated data

Description

Simulated dataset to illustrate the capability of segmented

Usage

data(simulData)

Arguments

Details

This dataset is employed to illustrate the capabilities of segmented in fitting segmented relationships with several breakpoints and constraints on the slope parameters.

Examples

Run this code
data(simulData)
## plot(simulData)

Run the code above in your browser using DataLab