confidence level of the interval. Default to 0.95.
Fieller
if TRUE, the Fieller's method is applied. Currently unimplemented.
digits
controls the number of digits to print when printing the output.
Value
A list of matrices. Each matrix includes point estimate and confidence limits of the breakpoint(s) for each
segmented variable in the model.
Details
Currently ci.psi computes confidence limits using the approximate standard errors of the estimated
breakpoints as reported in the `psi' component of the list returned by any segmented method. The resulting
confidence intervals are based on the asymptotic Normal distribution of the breakpoint
estimator which is reliable just for clear-cut kink relationships. See Details in segmented.