points.segmented: Points method for segmented objects
Description
Takes a fitted segmented object returned by segmented() and adds
on the current plot the joinpoints of the fitted broken-line relationships.
Usage
# S3 method for segmented
points(x, term, interc = TRUE, link = TRUE, rev.sgn=FALSE,
transf=I, .vcov=NULL, .coef=NULL, const=0, v=TRUE, ...)
Arguments
Details
We call 'joinpoint' the plane point having as coordinates the breakpoints (on the x scale) and the fitted values of
the segmented relationship at that breakpoints (on the y scale). points.segmented() simply adds the fitted
joinpoints on the current plot. This could be useful to emphasize the changes of the piecewise linear relationship.
See Also
plot.segmented to plot the fitted segmented lines.