logical indicating if output should be produced for each iteration.
last
logical indicating if output should include only the last fitted model.
maxit.glm
integer giving the maximum number of inner IWLS iterations (see details).
Value
A list with the arguments as components.
Details
Fitting a `segmented' model is attained via fitting iteratively standard GLMs. The number of iteration is
governed by it.max, while the (maximum) number of (inner) iterations to fit the GLM at each outer
iteration is fixed via maxit.glm. Usually three-four inner iterations will suffice.
If last=TRUE, the object resulting from segmented.lm (or segmented.glm) is a
list of fitted GLM; the i-th model is the segmented model with the values of the breakpoints at the i-th iteration.