Simulated dataset to illustrate the capability of segmented
Usage
data(simulData)
Arguments
Details
This dataset is employed to illustrate the capabilities of segmented
in fitting segmented relationships with several breakpoints and constraints on the
slope parameters.